<?php

class Mlumen_Install_Info {
	/**
	 * @var Mlumen_Options
	 */
	private $api_options;

	public function __construct( Mlumen_Options $options ) {
		$this->api_options = $options;

		// display message
		if ( ! $this->check_minimal_versions() ) {
			add_action( "admin_notices", array( $this, 'minimal_versions_message' ) );

		} elseif ( $this->check_display_info() ) {
			add_action( "admin_notices", array( $this, 'display_info' ) );
		}
	}

	/**
	 * Check whether to display
	 *
	 * @return boolean
	 */
	public function check_display_info() {
		global $pagenow;

		if ( $this->api_options->is_active_blog() ) {
			return false;
		}

		if ( ! current_user_can( 'manage_options' ) ) {
			return false;
		}

		if ( $pagenow === 'index.php' || $pagenow === 'plugins.php' ) {
			return true;
		}

		return false;
	}

	/**
	 * Display notification
	 */
	public function display_info() {
		?>

        <div class="notice notice-warning is-dismissible mlumen-info">
            <h2><?php echo __( 'Aktywuj bloga w aplikacji mLUMEN', 'mlumen' ); ?></h2>
            <h2>
                <a href="<?php echo add_query_arg( array( 'page' => 'mlumen' ), admin_url( 'options-general.php' ) ); ?>"
                   class="button button-default">
					<?php echo __( 'Przejdź do aktywacji', 'mlumen' ); ?>
                </a>
            </h2>
        </div>

		<?php
	}

	/**
	 * Check minimal version
	 *
	 * @return bool
	 */
	public function check_minimal_versions() {
		global $wp_version;

		if ( version_compare( $wp_version, MLUMEN_MINIMUM_WP_VERSION, '<' ) ) {
			return false;
		}

		if ( version_compare( PHP_VERSION, MLUMEN_MINIMUM_PHP_VERSION, '<' ) ) {
			return false;
		}

		return true;
	}

	/**
	 * Message minimal version
	 */
	public function minimal_versions_message() {
		global $wp_version;

		if ( version_compare( $wp_version, MLUMEN_MINIMUM_WP_VERSION, '<' ) ) {
            // translators: required minimum WordPress version
			$message = sprintf( esc_html__( 'mLUMEN wymaga WordPress w wersji %s lub nowszego.', 'mlumen' ), MLUMEN_MINIMUM_WP_VERSION );

		} elseif ( version_compare( PHP_VERSION, MLUMEN_MINIMUM_PHP_VERSION, '<' ) ) {
			// translators: required minimum PHP version
			$message = sprintf( esc_html__( 'mLUMEN wymaga PHP w wersji %s lub nowszej.', 'mlumen' ), MLUMEN_MINIMUM_PHP_VERSION );
		}

		if ( ! empty( $message ) ) {
			echo '<div class="notice notice-error is-dismissible mlumen-error"><p><strong>' . $message . '</strong></p></div>';
		}
	}
}

